# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetPoliciesResult',
    'AwaitableGetPoliciesResult',
    'get_policies',
    'get_policies_output',
]

@pulumi.output_type
class GetPoliciesResult:
    """
    A collection of values returned by getPolicies.
    """
    def __init__(__self__, enable_details=None, group_name=None, id=None, ids=None, name_regex=None, names=None, output_file=None, policies=None, role_name=None, type=None, user_name=None):
        if enable_details and not isinstance(enable_details, bool):
            raise TypeError("Expected argument 'enable_details' to be a bool")
        pulumi.set(__self__, "enable_details", enable_details)
        if group_name and not isinstance(group_name, str):
            raise TypeError("Expected argument 'group_name' to be a str")
        pulumi.set(__self__, "group_name", group_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if policies and not isinstance(policies, list):
            raise TypeError("Expected argument 'policies' to be a list")
        pulumi.set(__self__, "policies", policies)
        if role_name and not isinstance(role_name, str):
            raise TypeError("Expected argument 'role_name' to be a str")
        pulumi.set(__self__, "role_name", role_name)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if user_name and not isinstance(user_name, str):
            raise TypeError("Expected argument 'user_name' to be a str")
        pulumi.set(__self__, "user_name", user_name)

    @property
    @pulumi.getter(name="enableDetails")
    def enable_details(self) -> Optional[bool]:
        return pulumi.get(self, "enable_details")

    @property
    @pulumi.getter(name="groupName")
    def group_name(self) -> Optional[str]:
        return pulumi.get(self, "group_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        """
        A list of ram group names.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def policies(self) -> Sequence['outputs.GetPoliciesPolicyResult']:
        """
        A list of policies. Each element contains the following attributes:
        """
        return pulumi.get(self, "policies")

    @property
    @pulumi.getter(name="roleName")
    def role_name(self) -> Optional[str]:
        return pulumi.get(self, "role_name")

    @property
    @pulumi.getter
    def type(self) -> Optional[str]:
        """
        Type of the policy.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> Optional[str]:
        """
        The user name of  policy.
        """
        return pulumi.get(self, "user_name")


class AwaitableGetPoliciesResult(GetPoliciesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPoliciesResult(
            enable_details=self.enable_details,
            group_name=self.group_name,
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            policies=self.policies,
            role_name=self.role_name,
            type=self.type,
            user_name=self.user_name)


def get_policies(enable_details: Optional[bool] = None,
                 group_name: Optional[str] = None,
                 ids: Optional[Sequence[str]] = None,
                 name_regex: Optional[str] = None,
                 output_file: Optional[str] = None,
                 role_name: Optional[str] = None,
                 type: Optional[str] = None,
                 user_name: Optional[str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPoliciesResult:
    """
    This data source provides a list of RAM policies in an Alibaba Cloud account according to the specified filters.

    > **NOTE:** Available since v1.0.0+.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    policies_ds = alicloud.ram.get_policies(output_file="policies.txt",
        user_name="user1",
        group_name="group1",
        type="System")
    pulumi.export("firstPolicyName", policies_ds.policies[0].name)
    ```


    :param bool enable_details: Default to `true`. Set it to true can output more details.
    :param str group_name: Filter results by a specific group name. Returned policies are attached to the specified group.
    :param Sequence[str] ids: A list of ram group IDs.
    :param str name_regex: A regex string to filter resulting policies by name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str role_name: Filter results by a specific role name. Returned policies are attached to the specified role.
    :param str type: Filter results by a specific policy type. Valid values are `Custom` and `System`.
    :param str user_name: Filter results by a specific user name. Returned policies are attached to the specified user.
    """
    __args__ = dict()
    __args__['enableDetails'] = enable_details
    __args__['groupName'] = group_name
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['roleName'] = role_name
    __args__['type'] = type
    __args__['userName'] = user_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:ram/getPolicies:getPolicies', __args__, opts=opts, typ=GetPoliciesResult).value

    return AwaitableGetPoliciesResult(
        enable_details=pulumi.get(__ret__, 'enable_details'),
        group_name=pulumi.get(__ret__, 'group_name'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        policies=pulumi.get(__ret__, 'policies'),
        role_name=pulumi.get(__ret__, 'role_name'),
        type=pulumi.get(__ret__, 'type'),
        user_name=pulumi.get(__ret__, 'user_name'))
def get_policies_output(enable_details: Optional[pulumi.Input[Optional[bool]]] = None,
                        group_name: Optional[pulumi.Input[Optional[str]]] = None,
                        ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                        name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                        output_file: Optional[pulumi.Input[Optional[str]]] = None,
                        role_name: Optional[pulumi.Input[Optional[str]]] = None,
                        type: Optional[pulumi.Input[Optional[str]]] = None,
                        user_name: Optional[pulumi.Input[Optional[str]]] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetPoliciesResult]:
    """
    This data source provides a list of RAM policies in an Alibaba Cloud account according to the specified filters.

    > **NOTE:** Available since v1.0.0+.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    policies_ds = alicloud.ram.get_policies(output_file="policies.txt",
        user_name="user1",
        group_name="group1",
        type="System")
    pulumi.export("firstPolicyName", policies_ds.policies[0].name)
    ```


    :param bool enable_details: Default to `true`. Set it to true can output more details.
    :param str group_name: Filter results by a specific group name. Returned policies are attached to the specified group.
    :param Sequence[str] ids: A list of ram group IDs.
    :param str name_regex: A regex string to filter resulting policies by name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str role_name: Filter results by a specific role name. Returned policies are attached to the specified role.
    :param str type: Filter results by a specific policy type. Valid values are `Custom` and `System`.
    :param str user_name: Filter results by a specific user name. Returned policies are attached to the specified user.
    """
    __args__ = dict()
    __args__['enableDetails'] = enable_details
    __args__['groupName'] = group_name
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['roleName'] = role_name
    __args__['type'] = type
    __args__['userName'] = user_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:ram/getPolicies:getPolicies', __args__, opts=opts, typ=GetPoliciesResult)
    return __ret__.apply(lambda __response__: GetPoliciesResult(
        enable_details=pulumi.get(__response__, 'enable_details'),
        group_name=pulumi.get(__response__, 'group_name'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        policies=pulumi.get(__response__, 'policies'),
        role_name=pulumi.get(__response__, 'role_name'),
        type=pulumi.get(__response__, 'type'),
        user_name=pulumi.get(__response__, 'user_name')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ClientKeyArgs', 'ClientKey']

@pulumi.input_type
class ClientKeyArgs:
    def __init__(__self__, *,
                 aap_name: pulumi.Input[str],
                 password: pulumi.Input[str],
                 not_after: Optional[pulumi.Input[str]] = None,
                 not_before: Optional[pulumi.Input[str]] = None,
                 private_key_data_file: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a ClientKey resource.
        :param pulumi.Input[str] aap_name: ClientKey's parent Application Access Point name.
        :param pulumi.Input[str] password: To enhance security, set a password for the downloaded Client Key,When an application accesses KMS, you must use the ClientKey content and this password to initialize the SDK client.
        :param pulumi.Input[str] not_after: The ClientKey expiration time. Example: "2027-08-10 T08:03:30Z".
        :param pulumi.Input[str] not_before: The valid start time of the ClientKey. Example: "2022-08-10 T08:03:30Z".
        :param pulumi.Input[str] private_key_data_file: The name of file that can save access key id and access key secret. Strongly suggest you to specified it when you creating access key, otherwise, you wouldn't get its secret ever.
        """
        pulumi.set(__self__, "aap_name", aap_name)
        pulumi.set(__self__, "password", password)
        if not_after is not None:
            pulumi.set(__self__, "not_after", not_after)
        if not_before is not None:
            pulumi.set(__self__, "not_before", not_before)
        if private_key_data_file is not None:
            pulumi.set(__self__, "private_key_data_file", private_key_data_file)

    @property
    @pulumi.getter(name="aapName")
    def aap_name(self) -> pulumi.Input[str]:
        """
        ClientKey's parent Application Access Point name.
        """
        return pulumi.get(self, "aap_name")

    @aap_name.setter
    def aap_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "aap_name", value)

    @property
    @pulumi.getter
    def password(self) -> pulumi.Input[str]:
        """
        To enhance security, set a password for the downloaded Client Key,When an application accesses KMS, you must use the ClientKey content and this password to initialize the SDK client.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: pulumi.Input[str]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="notAfter")
    def not_after(self) -> Optional[pulumi.Input[str]]:
        """
        The ClientKey expiration time. Example: "2027-08-10 T08:03:30Z".
        """
        return pulumi.get(self, "not_after")

    @not_after.setter
    def not_after(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "not_after", value)

    @property
    @pulumi.getter(name="notBefore")
    def not_before(self) -> Optional[pulumi.Input[str]]:
        """
        The valid start time of the ClientKey. Example: "2022-08-10 T08:03:30Z".
        """
        return pulumi.get(self, "not_before")

    @not_before.setter
    def not_before(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "not_before", value)

    @property
    @pulumi.getter(name="privateKeyDataFile")
    def private_key_data_file(self) -> Optional[pulumi.Input[str]]:
        """
        The name of file that can save access key id and access key secret. Strongly suggest you to specified it when you creating access key, otherwise, you wouldn't get its secret ever.
        """
        return pulumi.get(self, "private_key_data_file")

    @private_key_data_file.setter
    def private_key_data_file(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "private_key_data_file", value)


@pulumi.input_type
class _ClientKeyState:
    def __init__(__self__, *,
                 aap_name: Optional[pulumi.Input[str]] = None,
                 create_time: Optional[pulumi.Input[str]] = None,
                 not_after: Optional[pulumi.Input[str]] = None,
                 not_before: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 private_key_data_file: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ClientKey resources.
        :param pulumi.Input[str] aap_name: ClientKey's parent Application Access Point name.
        :param pulumi.Input[str] create_time: Create timestamp, e.g. "2022-08-10T08:03:30Z".
        :param pulumi.Input[str] not_after: The ClientKey expiration time. Example: "2027-08-10 T08:03:30Z".
        :param pulumi.Input[str] not_before: The valid start time of the ClientKey. Example: "2022-08-10 T08:03:30Z".
        :param pulumi.Input[str] password: To enhance security, set a password for the downloaded Client Key,When an application accesses KMS, you must use the ClientKey content and this password to initialize the SDK client.
        :param pulumi.Input[str] private_key_data_file: The name of file that can save access key id and access key secret. Strongly suggest you to specified it when you creating access key, otherwise, you wouldn't get its secret ever.
        """
        if aap_name is not None:
            pulumi.set(__self__, "aap_name", aap_name)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if not_after is not None:
            pulumi.set(__self__, "not_after", not_after)
        if not_before is not None:
            pulumi.set(__self__, "not_before", not_before)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if private_key_data_file is not None:
            pulumi.set(__self__, "private_key_data_file", private_key_data_file)

    @property
    @pulumi.getter(name="aapName")
    def aap_name(self) -> Optional[pulumi.Input[str]]:
        """
        ClientKey's parent Application Access Point name.
        """
        return pulumi.get(self, "aap_name")

    @aap_name.setter
    def aap_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "aap_name", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        Create timestamp, e.g. "2022-08-10T08:03:30Z".
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="notAfter")
    def not_after(self) -> Optional[pulumi.Input[str]]:
        """
        The ClientKey expiration time. Example: "2027-08-10 T08:03:30Z".
        """
        return pulumi.get(self, "not_after")

    @not_after.setter
    def not_after(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "not_after", value)

    @property
    @pulumi.getter(name="notBefore")
    def not_before(self) -> Optional[pulumi.Input[str]]:
        """
        The valid start time of the ClientKey. Example: "2022-08-10 T08:03:30Z".
        """
        return pulumi.get(self, "not_before")

    @not_before.setter
    def not_before(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "not_before", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[str]]:
        """
        To enhance security, set a password for the downloaded Client Key,When an application accesses KMS, you must use the ClientKey content and this password to initialize the SDK client.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="privateKeyDataFile")
    def private_key_data_file(self) -> Optional[pulumi.Input[str]]:
        """
        The name of file that can save access key id and access key secret. Strongly suggest you to specified it when you creating access key, otherwise, you wouldn't get its secret ever.
        """
        return pulumi.get(self, "private_key_data_file")

    @private_key_data_file.setter
    def private_key_data_file(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "private_key_data_file", value)


class ClientKey(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 aap_name: Optional[pulumi.Input[str]] = None,
                 not_after: Optional[pulumi.Input[str]] = None,
                 not_before: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 private_key_data_file: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a KMS Client Key resource. Client key (of Application Access Point).

        For information about KMS Client Key and how to use it, see [What is Client Key](https://www.alibabacloud.com/help/zh/key-management-service/latest/api-createclientkey).

        > **NOTE:** Available since v1.210.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        aap0 = alicloud.kms.ApplicationAccessPoint("AAP0",
            policies=["aa"],
            description="aa",
            application_access_point_name=name)
        default = alicloud.kms.ClientKey("default",
            aap_name=aap0.application_access_point_name,
            password="YouPassword123!",
            not_before="2023-09-01T14:11:22Z",
            not_after="2028-09-01T14:11:22Z",
            private_key_data_file="./private_key_data_file.txt")
        ```

        ## Import

        KMS Client Key can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:kms/clientKey:ClientKey example <id>
        ```

        Resource attributes such as `password`, `private_key_data_file` are not available for imported resources as this information cannot be read from the KMS API.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] aap_name: ClientKey's parent Application Access Point name.
        :param pulumi.Input[str] not_after: The ClientKey expiration time. Example: "2027-08-10 T08:03:30Z".
        :param pulumi.Input[str] not_before: The valid start time of the ClientKey. Example: "2022-08-10 T08:03:30Z".
        :param pulumi.Input[str] password: To enhance security, set a password for the downloaded Client Key,When an application accesses KMS, you must use the ClientKey content and this password to initialize the SDK client.
        :param pulumi.Input[str] private_key_data_file: The name of file that can save access key id and access key secret. Strongly suggest you to specified it when you creating access key, otherwise, you wouldn't get its secret ever.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ClientKeyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a KMS Client Key resource. Client key (of Application Access Point).

        For information about KMS Client Key and how to use it, see [What is Client Key](https://www.alibabacloud.com/help/zh/key-management-service/latest/api-createclientkey).

        > **NOTE:** Available since v1.210.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        aap0 = alicloud.kms.ApplicationAccessPoint("AAP0",
            policies=["aa"],
            description="aa",
            application_access_point_name=name)
        default = alicloud.kms.ClientKey("default",
            aap_name=aap0.application_access_point_name,
            password="YouPassword123!",
            not_before="2023-09-01T14:11:22Z",
            not_after="2028-09-01T14:11:22Z",
            private_key_data_file="./private_key_data_file.txt")
        ```

        ## Import

        KMS Client Key can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:kms/clientKey:ClientKey example <id>
        ```

        Resource attributes such as `password`, `private_key_data_file` are not available for imported resources as this information cannot be read from the KMS API.

        :param str resource_name: The name of the resource.
        :param ClientKeyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ClientKeyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 aap_name: Optional[pulumi.Input[str]] = None,
                 not_after: Optional[pulumi.Input[str]] = None,
                 not_before: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 private_key_data_file: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ClientKeyArgs.__new__(ClientKeyArgs)

            if aap_name is None and not opts.urn:
                raise TypeError("Missing required property 'aap_name'")
            __props__.__dict__["aap_name"] = aap_name
            __props__.__dict__["not_after"] = not_after
            __props__.__dict__["not_before"] = not_before
            if password is None and not opts.urn:
                raise TypeError("Missing required property 'password'")
            __props__.__dict__["password"] = None if password is None else pulumi.Output.secret(password)
            __props__.__dict__["private_key_data_file"] = private_key_data_file
            __props__.__dict__["create_time"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["password"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(ClientKey, __self__).__init__(
            'alicloud:kms/clientKey:ClientKey',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            aap_name: Optional[pulumi.Input[str]] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            not_after: Optional[pulumi.Input[str]] = None,
            not_before: Optional[pulumi.Input[str]] = None,
            password: Optional[pulumi.Input[str]] = None,
            private_key_data_file: Optional[pulumi.Input[str]] = None) -> 'ClientKey':
        """
        Get an existing ClientKey resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] aap_name: ClientKey's parent Application Access Point name.
        :param pulumi.Input[str] create_time: Create timestamp, e.g. "2022-08-10T08:03:30Z".
        :param pulumi.Input[str] not_after: The ClientKey expiration time. Example: "2027-08-10 T08:03:30Z".
        :param pulumi.Input[str] not_before: The valid start time of the ClientKey. Example: "2022-08-10 T08:03:30Z".
        :param pulumi.Input[str] password: To enhance security, set a password for the downloaded Client Key,When an application accesses KMS, you must use the ClientKey content and this password to initialize the SDK client.
        :param pulumi.Input[str] private_key_data_file: The name of file that can save access key id and access key secret. Strongly suggest you to specified it when you creating access key, otherwise, you wouldn't get its secret ever.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ClientKeyState.__new__(_ClientKeyState)

        __props__.__dict__["aap_name"] = aap_name
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["not_after"] = not_after
        __props__.__dict__["not_before"] = not_before
        __props__.__dict__["password"] = password
        __props__.__dict__["private_key_data_file"] = private_key_data_file
        return ClientKey(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="aapName")
    def aap_name(self) -> pulumi.Output[str]:
        """
        ClientKey's parent Application Access Point name.
        """
        return pulumi.get(self, "aap_name")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        Create timestamp, e.g. "2022-08-10T08:03:30Z".
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="notAfter")
    def not_after(self) -> pulumi.Output[Optional[str]]:
        """
        The ClientKey expiration time. Example: "2027-08-10 T08:03:30Z".
        """
        return pulumi.get(self, "not_after")

    @property
    @pulumi.getter(name="notBefore")
    def not_before(self) -> pulumi.Output[Optional[str]]:
        """
        The valid start time of the ClientKey. Example: "2022-08-10 T08:03:30Z".
        """
        return pulumi.get(self, "not_before")

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[str]:
        """
        To enhance security, set a password for the downloaded Client Key,When an application accesses KMS, you must use the ClientKey content and this password to initialize the SDK client.
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="privateKeyDataFile")
    def private_key_data_file(self) -> pulumi.Output[Optional[str]]:
        """
        The name of file that can save access key id and access key secret. Strongly suggest you to specified it when you creating access key, otherwise, you wouldn't get its secret ever.
        """
        return pulumi.get(self, "private_key_data_file")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetLogConfigsResult',
    'AwaitableGetLogConfigsResult',
    'get_log_configs',
    'get_log_configs_output',
]

@pulumi.output_type
class GetLogConfigsResult:
    """
    A collection of values returned by getLogConfigs.
    """
    def __init__(__self__, configs=None, id=None, ids=None, log_type=None, output_file=None):
        if configs and not isinstance(configs, list):
            raise TypeError("Expected argument 'configs' to be a list")
        pulumi.set(__self__, "configs", configs)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if log_type and not isinstance(log_type, str):
            raise TypeError("Expected argument 'log_type' to be a str")
        pulumi.set(__self__, "log_type", log_type)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)

    @property
    @pulumi.getter
    def configs(self) -> Sequence['outputs.GetLogConfigsConfigResult']:
        return pulumi.get(self, "configs")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="logType")
    def log_type(self) -> Optional[str]:
        return pulumi.get(self, "log_type")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")


class AwaitableGetLogConfigsResult(GetLogConfigsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetLogConfigsResult(
            configs=self.configs,
            id=self.id,
            ids=self.ids,
            log_type=self.log_type,
            output_file=self.output_file)


def get_log_configs(ids: Optional[Sequence[str]] = None,
                    log_type: Optional[str] = None,
                    output_file: Optional[str] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetLogConfigsResult:
    """
    This data source provides the Api Gateway Log Configs of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.185.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.apigateway.get_log_configs(ids=["example_id"])
    pulumi.export("apiGatewayLogConfigId1", ids.configs[0].id)
    log_type = alicloud.apigateway.get_log_configs(log_type="PROVIDER")
    pulumi.export("apiGatewayLogConfigId2", log_type.configs[0].id)
    ```


    :param Sequence[str] ids: A list of Log Config IDs.
    :param str log_type: The type the of log. Valid values: `PROVIDER`.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['logType'] = log_type
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:apigateway/getLogConfigs:getLogConfigs', __args__, opts=opts, typ=GetLogConfigsResult).value

    return AwaitableGetLogConfigsResult(
        configs=pulumi.get(__ret__, 'configs'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        log_type=pulumi.get(__ret__, 'log_type'),
        output_file=pulumi.get(__ret__, 'output_file'))
def get_log_configs_output(ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                           log_type: Optional[pulumi.Input[Optional[str]]] = None,
                           output_file: Optional[pulumi.Input[Optional[str]]] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetLogConfigsResult]:
    """
    This data source provides the Api Gateway Log Configs of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.185.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.apigateway.get_log_configs(ids=["example_id"])
    pulumi.export("apiGatewayLogConfigId1", ids.configs[0].id)
    log_type = alicloud.apigateway.get_log_configs(log_type="PROVIDER")
    pulumi.export("apiGatewayLogConfigId2", log_type.configs[0].id)
    ```


    :param Sequence[str] ids: A list of Log Config IDs.
    :param str log_type: The type the of log. Valid values: `PROVIDER`.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['logType'] = log_type
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:apigateway/getLogConfigs:getLogConfigs', __args__, opts=opts, typ=GetLogConfigsResult)
    return __ret__.apply(lambda __response__: GetLogConfigsResult(
        configs=pulumi.get(__response__, 'configs'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        log_type=pulumi.get(__response__, 'log_type'),
        output_file=pulumi.get(__response__, 'output_file')))
